@@ -8,6 +8,7 @@ Net::Simplify::Deposit - A Simplify Commerce Deposit object
 
   use Net::Simplify;
 
+
   $Net::Simplify::public_key = 'YOUR PUBLIC KEY';
   $Net::Simplify::private_key = 'YOUR PRIVATE KEY';
 
@@ -16,7 +17,7 @@ Net::Simplify::Deposit - A Simplify Commerce Deposit object
 
   # Retrieve a list of objects
   my $deposits = Net::Simplify::Deposit->list({max => 10});
-  foreach my $$deposit ($deposits->list) {
+  foreach my $v ($deposits->list) {
       # ...
   }
 
@@ -116,7 +117,7 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.3
+1.0.4
 
 =head1 LICENSE
 
